ZODB programming guide — ZODB documentation

# ZODB programming guide

This guide consists of a collection of topics that should be of interest to most developers. They’re provuded in order of importance, which is also an order from least to most advanced, but they can be read in any order.

If you haven’t yet, you should read the Tutorial.

- Installing and running ZODB
  - Installation
  - Configuration
  - Using databases: connections
- Writing persistent objects
  - Access and modification
  - Rules of persistence
  - Properties
  - Special attributes
  - Object storage and management
  - You can’t change your mind in subclassing persistent
  - Schema migration
  - Object life cycle states and special attributes (advanced)
  - Other things you can do, but shouldn’t (advanced)
  - Links
- Transactions and concurrency
  - Using transactions
  - ZODB and atomicity
  - Concurrency, threads and processes